package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.format.FormatElement;
import com.ynet.gene.format.GENEFormatException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/VirtualHostCommAction.class */
public class VirtualHostCommAction extends LifeAction {
    public static final boolean MASK_PASSWORD = true;
    public static final String MASK_BEGIN_TAG = "<password>";
    public static final String MASK_END_TAG = "</password>";
    public static final String MASK_CONTENT = "<password>****</password>";
    private static final int DEFAULT_TIMEOUT = 5000;
    private static final int REQUEST_LENGTH = 8;
    public static final String FIELD_HOST_DATA_ID = "gatewayData";
    private static final String ERROR_CODE_PACK = "EBLN0010";
    private static final String ERROR_CODE_POOL = "EBLN0011";
    private static final String ERROR_CODE_LOSEDATA = "EBLN0012";
    private static final String ERROR_CODE_TIMEOUT = "EBLN0013";
    private static final String ERROR_CODE_UNPACK = "EBLN0014";
    private static final String ERROR_CODE_GATEWAY = "EBLN0015";
    private String hostCode;
    private String sendFormatName;
    private String receiveFormatName;
    private String recMsgDataName;
    private String httpResource;
    public static final String FIELD_HOST_RETURN_CODE = "hostReturnCode";
    public static final String FIELD_HOST_ERROR_MESSAGE = "hostErrorMessage";

    public String execute(Context context) throws GENEException {
        FormatElement sendFormatElement = context.getFormat(this.sendFormatName);
        if (sendFormatElement == null) {
            Trace.logError("LifeAction", "EBLN0010：发送报文格式未定义");
            throw new TranFailException(ERROR_CODE_PACK, "发送报文格式未定义");
        }
        try {
            sendFormatElement.format(context);
            String localMessage = readLocalFile();
            print("----返回报文----\n" + localMessage + "\n");
            FormatElement receiveFormatElement = context.getFormat(this.receiveFormatName);
            if (receiveFormatElement == null) {
                Trace.logError("LifeAction", "EBLN0010：接收报文格式未定义");
                throw new TranFailException(ERROR_CODE_PACK, "接收报文格式未定义");
            }
            try {
                receiveFormatElement.unFormat(localMessage, context);
                try {
                    if (dealResult(context) != 0) {
                        return "1";
                    }
                    return "0";
                } catch (TranFailException te) {
                    Trace.logError("LifeAction", te.getShowMessage(), te);
                    throw te;
                }
            } catch (Exception ex) {
                Trace.logError("LifeAction", "EBLN0010：返回报文解包失败", ex);
                throw new TranFailException(ERROR_CODE_PACK, "返回报文解包失败", ex);
            }
        } catch (GENEFormatException ex2) {
            Trace.logError("LifeAction", "EBLN0010：发送报文格式化失败", ex2);
            throw new TranFailException(ERROR_CODE_PACK, "发送报文格式化失败", ex2);
        }
    }

    protected List getReqHeadParams() {
        List params = new ArrayList();
        params.add("$gatewayData.gwPkgType,2");
        params.add("$gatewayData.gwTrxCode,6");
        params.add("$gatewayData.gwMsgType,1");
        params.add("$gatewayData.gwReqTime,14");
        params.add("$gatewayData.gwFlwNo,8");
        params.add("$gatewayData.gwReqChannel,2");
        params.add("$gatewayData.gwBrchETellerNo,8");
        params.add("$gatewayData.gwRsCode,6");
        params.add("$gatewayData.gwReserveMe,32");
        params.add("$gatewayData.gwRsResultFlag,1");
        params.add("$gatewayData.hBrchNo,3");
        params.add("$gatewayData.hBrchClrNo,7");
        params.add("$gatewayData.hBrchETellerNo,8");
        return params;
    }

    protected String getGWHead(Context context, List headParams) throws GENEException {
        StringBuffer temp;
        StringBuffer result = new StringBuffer();
        if (headParams != null) {
            for (int i = 0; i < headParams.size(); i++) {
                String param = (String) headParams.get(i);
                boolean isField = param.startsWith("$");
                int idx = param.indexOf(",");
                int len = Integer.parseInt(param.substring(idx + 1).trim());
                if (isField) {
                    temp = new StringBuffer((String) context.getDataValue(param.substring(1, idx)));
                } else {
                    temp = new StringBuffer(param.substring(0, idx));
                }
                if (temp.length() < len) {
                    for (int k = temp.length(); k < len; k++) {
                        temp.append(" ");
                    }
                    result.append(temp);
                } else if (temp.length() > len) {
                    result.append(temp.substring(0, len));
                } else {
                    result.append(temp);
                }
            }
        }
        return result.toString();
    }

    protected void prepareData(Context context) throws GENEException {
        KeyedCollection dataKcoll = new KeyedCollection("gatewayData");
        dataKcoll.addDataField("gwPkgType", "01");
        dataKcoll.addDataField("gwMsgType", "01");
        dataKcoll.addDataField("gwTrxCode", this.hostCode);
        dataKcoll.addDataField("gwReqTime", LifeStandard.getServerTime("yyyyMMddHHmmss"));
        dataKcoll.addDataField("gwFlwNo", "00000000");
        dataKcoll.addDataField("gwReqChannel", "01");
        dataKcoll.addDataField("gwBrchETellerNo", "0000");
        dataKcoll.addDataField("gwRsCode", "000000");
        dataKcoll.addDataField("gwReserveMe", "");
        dataKcoll.addDataField("gwRsResultFlag", "Y");
        dataKcoll.addDataField("hBrchNo", "0000");
        dataKcoll.addDataField("hBrchETellerNo", "0000");
        context.addDataElement(dataKcoll);
    }

    private int dealResult(Context context) throws TranFailException {
        int result;
        String hostReturnCode = (String) context.get("hostReturnCode");
        if (hostReturnCode == null) {
            throw new TranFailException("EBLN0000", "无法获取交易结果代码hostReturnCode");
        }
        try {
            result = Integer.parseInt(hostReturnCode);
        } catch (NumberFormatException unused) {
            result = 1;
        }
        if (result != 0) {
            String hostErrorMessage = null;
            try {
                hostErrorMessage = (String) context.getDataValue("hostErrorMessage");
            } catch (GENEException ex) {
                Trace.logWarning("LifeAction", ex.getMessage(), ex);
            }
            if (hostErrorMessage == null) {
                LifeErrorInfo error = LifeStandard.getErrorInfo(hostReturnCode);
                if (error == null) {
                    throw new TranFailException(hostReturnCode, "未知的错误代码");
                }
                hostErrorMessage = error.getShowMsg();
            }
            context.put("GENEException", new TranFailException(hostReturnCode, hostErrorMessage, false));
        }
        return result;
    }

    private String maskMessage(String message) {
        Vector passVector = getSegmentsStr(LifeStandard.getBankSettingsValue("PasswordFields_Masked"), ",");
        for (int i = 0; i < passVector.size(); i++) {
            String subStr = ((String) passVector.elementAt(i)).trim();
            if (!"".equals(subStr)) {
                String subStrEnd = "</" + ("<" + subStr + ">") + ">";
                String subStr2 = "******".concat(String.valueOf(subStrEnd));
                int tagBeginPos = message.indexOf(subStr2);
                if (tagBeginPos >= 0) {
                    int tagEndPos = message.indexOf(subStrEnd) + subStrEnd.length();
                    return String.valueOf(message.substring(0, tagBeginPos)) + subStr2 + message.substring(tagEndPos);
                }
            }
        }
        return message;
    }

    private String readLocalFile() {
        InputStreamReader read = null;
        BufferedReader in = null;
        String message = null;
        try {
            try {
                String rootPath = LifeStandard.getRootPath();
                String virtualHostFileName = String.valueOf(rootPath) + "WEB-INF/virtualhost/" + this.hostCode + ".txt";
                File virtualHostFile = new File(virtualHostFileName);
                if (!virtualHostFile.exists()) {
                    Trace.logError("LifeFile", "读取本地文件出错");
                }
                read = new InputStreamReader(new FileInputStream(virtualHostFile), "UTF-8");
                in = new BufferedReader(read);
                StringBuffer sb = new StringBuffer();
                while (true) {
                    String line = in.readLine();
                    if (line == null) {
                        break;
                    }
                    sb = sb.append(line);
                }
                message = sb.toString();
                try {
                    in.close();
                    read.close();
                } catch (IOException unused) {
                }
            } catch (Exception e) {
                Trace.logError("LifeFile", "读取本地文件出错", e);
                if (in != null) {
                    try {
                        in.close();
                    } catch (IOException unused2) {
                    }
                }
                if (read != null) {
                    read.close();
                }
            }
            return message;
        } catch (Throwable th) {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException unused3) {
                    throw th;
                }
            }
            if (read != null) {
                read.close();
            }
            throw th;
        }
    }

    private void print(String message) {
        Trace.logDebug("LifeHTTP", maskMessage(message));
    }

    public void setHostCode(String hostCode) {
        this.hostCode = hostCode;
    }

    public void setSendFormatName(String sendFormatName) {
        this.sendFormatName = sendFormatName;
    }

    public void setReceiveFormatName(String receiveFormatName) {
        this.receiveFormatName = receiveFormatName;
    }

    public void setRecMsgDataName(String recMsgDataName) {
        this.recMsgDataName = recMsgDataName;
    }

    public void setHttpResource(String httpResource) {
        this.httpResource = httpResource;
    }

    private static Vector getSegmentsStr(String str, String token) {
        Vector vocter = new Vector(1);
        StringTokenizer st = new StringTokenizer(str, token);
        while (st.hasMoreTokens()) {
            String des = st.nextToken();
            vocter.addElement(des);
        }
        return vocter;
    }
}
